#!/usr/bin/gnuplot -persist
#  
#    	G N U P L O T
#    	Version 4.0 patchlevel 0
#
#	Standard Settings for GPI
#       (c) 2005 Michael Goerz
#       http://www.physik.fu-berlin.de/~goerz/gp1/plotsettings_en.html
#
# See http://t16web.lanl.gov/Kawano/gnuplot/index-e.html
# for a good introduction to Gnuplot
#
# remember the 'help' command


# To save the plot to a postscript file, use
set terminal postscript enhanced
set output 'correct.ps'


unset key
set tics in
set ticslevel 0.5
set ticscale 1 0.5
set mxtics 10
set mytics 10
set nox2tics
set noy2tics
set fit noerrorvariables
set grid xtics mxtics ytics mytics noztics nomztics

# If you want logscale, change this to 'set'
# You can use 'logscale x', 'logscale y', 'logscale xy'
unset logscale

set title ""
set xlabel "Steuerstrom  /  mA"
set ylabel "Hallspannung  /  mA"

# To set the plot ranges, use the following
# First look at the automatic output, then adjust manually
set xrange [0:55]
# set yrange [0:10]

f(x) = -1.22137 * x
e1(x) = -1.22132 * x
e2(x) = -1.22142 * x

plot f(x) linetype 1 linewidth 1, \
     e1(x) linetype 0 linewidth 1, \
     e2(x) linetype 0 linewidth 1, \
     "correct_data.csv" with yerrorbars linetype 1 linewidth 1 pointtype 7 pointsize .5


######################################################

set output 'magcalibrat.ps'

set title ""
set xlabel "Magnetfeldstrom  /  A"
set ylabel "Magnetfeld  /  mT"

# To set the plot ranges, use the following
# First look at the automatic output, then adjust manually
set xrange [0:1.8]
# set yrange [0:10]

f(x) = 136.519 * x
e1(x) = 139.433 * x
e2(x) = 133.606 * x

plot f(x) linetype 1 linewidth 1, \
     e1(x) linetype 0 linewidth 1, \
     e2(x) linetype 0 linewidth 1, \
     "magcalibration.csv" with yerrorbars linetype 1 linewidth 1 pointtype 7 pointsize .5

######################################################

set output 'assg1a.ps'

set title ""
set xlabel "IB/d  /  mA T/m"
set ylabel "Hallspannung  /  mV"

# To set the plot ranges, use the following
# First look at the automatic output, then adjust manually
set xrange [0:13000]
# set yrange [0:10]

f(x) = 0.0071286 * x
e1(x) = 0.00722585 * x
e2(x) = 0.00703134 * x

plot f(x) linetype 1 linewidth 1, \
     e1(x) linetype 0 linewidth 1, \
     e2(x) linetype 0 linewidth 1, \
     "assg1a.csv" with yerrorbars linetype 1 linewidth 1 pointtype 7 pointsize .5

######################################################

set output 'assg1a_n.ps'

set title ""
set xlabel "edU/I  /  C m mV/A"
set ylabel "Magnetfeld  /  mT"

# To set the plot ranges, use the following
# First look at the automatic output, then adjust manually
set xrange [2.82E-020:2.79E-019]

f(x) = 8.77251E20 * x
e1(x) = 8.90263E20 * x
e2(x) = 8.64439E20 * x

plot f(x) linetype 1 linewidth 1, \
     e1(x) linetype 0 linewidth 1, \
     e2(x) linetype 0 linewidth 1, \
     "assg1a_n.csv" with yerrorbars linetype 1 linewidth 1 pointtype 7 pointsize .5


######################################################

set output 'assg1b.ps'

set title ""
set xlabel "IB/d  /  mA T/m"
set ylabel "Hallspannung  /  mV"

# To set the plot ranges, use the following
# First look at the automatic output, then adjust manually
set xrange [0:13000]
# set yrange [0:10]

f(x) = 0.00711093 * x
e1(x) = 0.00719982 * x
e2(x) = 0.00702204 * x

plot f(x) linetype 1 linewidth 1, \
     e1(x) linetype 0 linewidth 1, \
     e2(x) linetype 0 linewidth 1, \
     "assg1b.csv" with yerrorbars linetype 1 linewidth 1 pointtype 7 pointsize .5

######################################################

set output 'assg1b_n.ps'

set title ""
set xlabel "edU/B  /  C m mV/T"
set ylabel "Steuerstrom  /  mA"

# To set the plot ranges, use the following
# First look at the automatic output, then adjust manually
set xrange [6.55E-021:5.75E-020]

f(x) = 8.77665E20 * x
e1(x) = 8.89002E20 * x
e2(x) = 8.66327E20 * x

plot f(x) linetype 1 linewidth 1, \
     e1(x) linetype 0 linewidth 1, \
     e2(x) linetype 0 linewidth 1, \
     "assg1b_n.csv" with yerrorbars linetype 1 linewidth 1 pointtype 7 pointsize .5

######################################################

set output 'assg2.ps'

set title ""
set xlabel "Temperatur  /  K"
set ylabel "Hallspannung  /  mV"

# To set the plot ranges, use the following
# First look at the automatic output, then adjust manually
set xrange [300:425]

#f(x) = 8.77665E20 * x
#e1(x) = 8.89002E20 * x
#e2(x) = 8.66327E20 * x

plot "assg2.csv" with yerrorbars linetype 1 linewidth 1 pointtype 7 pointsize .5

#    EOF
