(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     79335,       1656]*)
(*NotebookOutlinePosition[     80294,       1685]*)
(*  CellTagsIndexPosition[     80250,       1681]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Linear Regression", "Title"],

Cell["\<\
Michael Goerz
10.09.2005\
\>", "Text"],

Cell[CellGroupData[{

Cell["Preamble", "Section"],

Cell[CellGroupData[{

Cell["Options", "Subsubsection"],

Cell[BoxData[
    \(\(SetDirectory["\</home/goerz/GP2/HAL\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(Off[General::"\<spell1\>"];\)\)], "Input"],

Cell[BoxData[
    \(<< \ Statistics`DataManipulation`\)], "Input"],

Cell[BoxData[
    \(<< \ Graphics`Graphics`\)], "Input"],

Cell[BoxData[
    \(<< Statistics`LinearRegression`\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some Regular Expressions (As Reference)", "Subsubsection"],

Cell[TextData[{
  "The following shell commands can be useful for filtering datafiles:\n\n",
  StyleBox["grep '[.0-9]\\|^#\\|^[[:space:]]$' data.csv", "Program"],
  "\nThis leaves any lines with data, gnuplot comment lines, and blank lines\n\
\n",
  StyleBox["grep '[.0-9]\\|^[[:space:]]$' data.csv", "Program"],
  "\nThis leaves any lines with data, and blank lines\n\n",
  StyleBox["grep '[.0-9]' data.csv", "Program"],
  "\nThis leaves only lines with data"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Subsubsection"],

Cell["\<\
Data is loaded from the file 'data.csv'. The file ist assumed to \
contain three collumns, the x-value, the y-value, and the y-error\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dataset = ReadList["\<assg1b.csv\>", {Real, Real, \ Real}]\)], "Input"],

Cell[BoxData[
    \({{1427.09`, 10.1`, 0.9`}, {2485.11`, 17.6`, 1.1`}, {3666.15`, 26.1`, 
        1.5`}, {4355.09`, 31.`, 1.7`}, {5044.03`, 36.`, 1.9`}, {5831.39`, 
        41.6`, 2.1`}, {6348.09`, 45.3`, 2.3`}, {6889.4`, 49.2`, 
        2.5`}, {7578.34`, 54.`, 2.7`}, {8291.89`, 59.1`, 2.9`}, {8685.57`, 
        61.8`, 3.`}, {9251.48`, 65.8`, 3.2`}, {10038.84`, 71.4`, 
        3.4`}, {10555.55`, 75.`, 3.6`}, {11096.86`, 78.6`, 3.8`}, {11662.77`, 
        82.5`, 3.9`}, {12499.34`, 88.4`, 4.2`}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell[CellGroupData[{

Cell["Standard Functions for Linear Regression", "Subsubsection"],

Cell[BoxData[
    RowBox[{\(LinReg[daten_]\), ":=", " ", "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, \[CapitalDelta]y, \ 
            S\ , \[CapitalDelta]a0, \[CapitalDelta]b0, \ a0, \ b0, n, 
            Rsqared0, \[Chi]Squared0}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\(n = Length[daten]\), ";", 
            "\[IndentingNewLine]", \(x = Column[daten, 1]\), ";", 
            "\[IndentingNewLine]", \(y = Column[daten, \ 2]\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]y = Column[daten, 3]\), 
            ";", "\[IndentingNewLine]", \(S = \[Sum]\+\(i = 1\)\%n\( 
                        1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\((x\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) - \((\[Sum]\+\(i = 1\)\%n \
x\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\^2\), ";", 
            "\[IndentingNewLine]", \(a0 = \(1\/S\) \((\[Sum]\+\(i = \
1\)\%n\(\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\
\(i = 1\)\%n y\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \[Sum]\+\(i = 1\)\%n\( 
                              x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( x\
\[LeftDoubleBracket]i\[RightDoubleBracket]\ y\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\))\)\), ";", 
            RowBox[{
              RowBox[{Cell[""], "b0"}], 
              "=", \(\(1\/S\) \((\[Sum]\+\(i = 1\)\%n\( 
                            1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]i\
\[RightDoubleBracket]\ y\[LeftDoubleBracket]i\[RightDoubleBracket]\)\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \[Sum]\+\
\(i = 1\)\%n\( 
                              x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\(\(\
\ \)\(y\[LeftDoubleBracket]i\[RightDoubleBracket]\)\)\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\)\)}], ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]a0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = \
1\)\%n\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]\
y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)\)\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]b0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = 1\)\%n 1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\)\)\), ";", 
            "\[IndentingNewLine]", \(Rsqared0 = 
              1 - \((\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)/\
\((\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - \((\
\[Sum]\+\(i = 1\)\%n\( y\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\
\(i = 1\)\%n \
1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\))\)\
\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\),
             ";", "\[IndentingNewLine]", \(\[Chi]Sqared0 = \[Sum]\+\(i = \
1\)\%n\((\(1\/\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket]\) \
\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - a0 - b0\ x\
\[LeftDoubleBracket]i\[RightDoubleBracket])\))\)\^2\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print["\<Errors from dataset\>"]\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print["\<Number of data points: \>", 
              n]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print[
              
              TableForm[{{"\<\>", "\<Value\>", \ "\<Error\>"}, {"\<Slope \
b\>", \ b0, \ \[CapitalDelta]b0}, {"\<y-Intercept a\>", \ 
                    a0, \ \[CapitalDelta]a0}}]]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\>"]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of best fit: y = \>", 
              b0, "\< * x + \>", a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of top worst fit: y = \
\>", b0 + \[CapitalDelta]b0, "\< * x +\>", \ a0 + \[CapitalDelta]a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of bottom worst fit: y \
= \>", b0 - \[CapitalDelta]b0, "\< * x + \>", a0 - \[CapitalDelta]a0]\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print["\<\n\>", \*"\"\<Certainty Measure \
\!\(R\^2\): \>\"", \ Rsqared0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\n\>", \*"\"\<Quality of the \
Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 2\)\): \>\"", \[Chi]Sqared0\/\(n - \
2\)]\), ";", 
            "\[IndentingNewLine]", \( (*Error\ too\ small\ if\ s\^2\  > \ 
                0, \ Error\ too\ large\ if\ s\^2\  < \ 0*) \), 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \({b \[Rule] \ 
                b0, \ \[CapitalDelta]b\  \[Rule] \ \[CapitalDelta]b0, \ 
              a \[Rule] \ 
                a0, \ \[CapitalDelta]a \[Rule] \ \[CapitalDelta]a0, \ 
              Rsqared \[Rule] \ 
                Rsqared0, \ \[Chi]Sqared\  \[Rule] \ \[Chi]Sqared0, \ 
              sSquared\  \[Rule] \[Chi]Sqared0\/\(n - 2\)\ }\)}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Regression with Error Taken from Weighted Variance", \
"Subsubsection"],

Cell[BoxData[
    RowBox[{\(LinRegWeightedVariance[daten_]\), ":=", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, f, \ S\ , \[CapitalDelta]a0, \[CapitalDelta]b0, \ 
            a0, \ b0, n, Rsqared0, \ \[Chi]Sqared0}\), ",", 
          "\[IndentingNewLine]", 
          
          RowBox[{\(n = Length[daten]\), ";", 
            "\[IndentingNewLine]", \(x = Column[daten, 1]\), ";", 
            "\[IndentingNewLine]", \(y = Column[daten, \ 2]\), ";", 
            "\[IndentingNewLine]", \( (*Fuer\ die\ f\_i\ muessen\ die\ \
\[CapitalDelta]y\_i\ verwendet\ werden*) \), 
            "\[IndentingNewLine]", \(f = Column[daten, 3]\), ";", 
            "\[IndentingNewLine]", \(S = \[Sum]\+\(i = 1\)\%n\( 
                        1\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^\
2\) \(\[Sum]\+\(i = \
1\)\%n\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \((\[Sum]\+\(i = 1\)\%n \
x\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2)\)\^2\), ";", 
            "\[IndentingNewLine]", \(a0 = \(1\/S\) \((\[Sum]\+\(i = \
1\)\%n\(\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n y\
\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) - \[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]\
i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( \
x\[LeftDoubleBracket]i\[RightDoubleBracket]\ y\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\
\))\)\), ";", 
            RowBox[{
              RowBox[{Cell[""], "b0"}], 
              "=", \(\(1\/S\) \((\[Sum]\+\(i = 1\)\%n\( 
                            1\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]i\[RightDoubleBracket]\ \
y\[LeftDoubleBracket]i\[RightDoubleBracket]\)\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) - \[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]\
i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\(\(\ \)\(y\
\[LeftDoubleBracket]i\[RightDoubleBracket]\)\)\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\))\)\)}], ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]a0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = \
1\)\%n\((\(\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(1\/\(n - 2\)\) \
\(\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - a0 - \
b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\)\)\)\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]b0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = 1\)\%n\((\(1\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\) \(1\/\(n - 2\)\) \(\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\)\)\)\), ";", 
            "\[IndentingNewLine]", \(Rsqared0 = 
              1 - \((\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)/\((\[Sum]\+\(i \
= 1\)\%n\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - \((\[Sum]\+\(i = 1\)\
\%n\( y\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n 1\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\))\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\), ";", 
            "\[IndentingNewLine]", \(\[Chi]Sqared0 = \[Sum]\+\(i = \
1\)\%n\((\(1\/f\[LeftDoubleBracket]i\[RightDoubleBracket]\) \((y\
\[LeftDoubleBracket]i\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\
\[RightDoubleBracket])\))\)\^2\), ";", 
            "\[IndentingNewLine]", \(Print["\<Errors from variance\>"]\), ";",
             "\n", "\[IndentingNewLine]", \(Print["\<Number of data points: \
\>", n]\), ";", "\n", 
            "\[IndentingNewLine]", \(Print[
              TableForm[{{"\<\>", "\<Value\>", \ "\<Error\>"}, {"\<Slope \
b\>", \ b0, \ \[CapitalDelta]b0}, {"\<y-Intercept a\>", \ 
                    a0, \ \[CapitalDelta]a0}}]]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\>"]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of best fit: y = \>", 
              b0, "\< * x + \>", a0]\), 
            ";", \(Print["\<Equation of top worst fit: y = \>", 
              b0 + \[CapitalDelta]b0, "\< * x + \>", 
              a0 + \[CapitalDelta]a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of bottom worst fit: y \
= \>", b0 - \[CapitalDelta]b0, "\< * x + \>", a0 - \[CapitalDelta]a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\n\>", \*"\"\<Quality of the \
Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 2\)\): \>\"", \[Chi]Sqared0\/\(n - \
2\)]\), ";", \(Print["\<\n\>", \*"\"\<Certainty Measure \!\(R\^2\): \>\"", \ 
              Rsqared0]\), ";", 
            "\n", \( (*Error\ too\ small\ if\ s\^2\  > \ 0, \ 
              Error\ too\ large\ if\ s\^2\  < \ 0*) \), "\[IndentingNewLine]",
             "\[IndentingNewLine]", \({b \[Rule] \ 
                b0, \ \[CapitalDelta]b\  \[Rule] \ \[CapitalDelta]b0, \ 
              a \[Rule] \ 
                a0, \ \[CapitalDelta]a \[Rule] \ \[CapitalDelta]a0, \ 
              Rsqared \[Rule] \ 
                Rsqared0, \ \[Chi]Sqared\  \[Rule] \ \[Chi]Sqared0, 
              sSquared\  \[Rule] \[Chi]Sqared0\/\(n - 2\)}\)}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Regression for a Straight Line from the Origin", "Subsubsection"],

Cell[BoxData[
    \(LinRegOrigin[
        daten_] := \[IndentingNewLine]Module[{x, y, \[CapitalDelta]y, 
          S, \[CapitalDelta]b0, b0, n, ybar0, 
          Rsq0, \[Chi]sq0}, \[IndentingNewLine]n = 
          Length[daten]; \[IndentingNewLine]x = 
          Column[daten, 1]; \[IndentingNewLine]y = 
          Column[daten, 2]; \[IndentingNewLine]\[CapitalDelta]y = 
          Column[daten, 
            3]; \[IndentingNewLine]S = \[Sum]\+\(i = 1\)\%n 1\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2*\(\[Sum]\+\(\
i = 1\)\%n\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \
\((\[Sum]\+\(i = 1\)\%n x\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\^2; \
\[IndentingNewLine]b0 = \[Sum]\+\(i = 1\)\%n\(\( x\[LeftDoubleBracket]
                      i\[RightDoubleBracket]*
                    y\[LeftDoubleBracket]
                      i\[RightDoubleBracket]\)\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n\((x\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)\ ; \[IndentingNewLine]\
\[CapitalDelta]b0 = 
          Sqrt[1/\(\[Sum]\+\(i = 1\)\%n\((x\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\)]; \[IndentingNewLine]ybar0 = \[Sum]\+\(i = \
1\)\%n\( y\[LeftDoubleBracket]
                    i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n 1\/\
\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\); \
\[IndentingNewLine]Rsq0 = 
          1 - \[Sum]\+\(i = 1\)\%n\(\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - \
b0*x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n\((y\
\[LeftDoubleBracket]i\[RightDoubleBracket] - ybar0)\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\); \
\[IndentingNewLine]\[Chi]sq0 = \[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - \
b0*x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2; \
\[IndentingNewLine]Print["\<Errors from dataset\>"]; \
\[IndentingNewLine]Print["\<Number of data points: \>", 
          n]; \[IndentingNewLine]Print[
          TableForm[{{"\<\>", "\<Value\>", "\<Error\>"}, {"\<Slope b\>", 
                b0, \[CapitalDelta]b0}}]]; \[IndentingNewLine]Print["\<\>"]; \
\[IndentingNewLine]Print["\<Equation of best fit: y =\>", 
          b0, "\<* x\>"]; \[IndentingNewLine]Print["\<Equation of top worst \
fit: y = \>", 
          b0 + \[CapitalDelta]b0, "\< * x\>"]; \
\[IndentingNewLine]Print["\<Equation of bottom worst fit: y = \>", 
          b0 - \[CapitalDelta]b0, "\< * x\>"]; \
\[IndentingNewLine]Print["\<\>"]; \[IndentingNewLine]Print[\*"\"\<Certainty \
Measure \!\(R\^2\): \>\"", 
          Rsq0]; \[IndentingNewLine]Print[\*"\"\<Quality of Errors \
\!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 1\)\): \>\"", \[Chi]sq0\/\(n - 1\)]; \ \
\[IndentingNewLine]{a \[Rule] 0, \[CapitalDelta]a \[Rule] \ 0, 
          b -> \ b0, \ \[CapitalDelta]b -> \[CapitalDelta]b0, 
          Rsqared -> Rsq0, \ \[Chi]Sqared\  \[Rule] \ \[Chi]sq0, 
          sSquared\  \[Rule] \[Chi]sq0\/\(n - 2\)}\[IndentingNewLine]]\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Instructions for Exponential Data", "Subsubsection"],

Cell["\<\
It is best to linearize exponential data first with the following \
command:\
\>", "Text"],

Cell[BoxData[
    \(\(linearize[expdata_] := 
        Replace[expdata, {xi_, yi_, \[CapitalDelta]yi_} \[Rule] \ {xi, 
              Log[yi], \((1/yi)\)*\[CapitalDelta]yi}, 2];\)\)], "Input"],

Cell["\<\
Then, you can apply the functions for linear data. If you want to \
plot the data as exponential functions later, simply raise the full right \
hand side of the fit equation into the exponent.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exporting Data", "Subsubsection"],

Cell[TextData[{
  "To export data to a file, use\n",
  Cell[BoxData[
      \(Export["\<data.csv\>", dataset, \ "\<Table\>"]\)], "Input"]
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Application", "Section"],

Cell[CellGroupData[{

Cell["Calculation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(parameter = LinRegOrigin[dataset];\)\)], "Input"],

Cell[BoxData[
    \("Errors from dataset"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of data points: "\[InvisibleSpace]17\),
      SequenceForm[ "Number of data points: ", 17],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Value\"\>", "\<\"Error\"\>"},
          {"\<\"Slope b\"\>", "0.007110932948529668`", 
            "0.0000888891283439971`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of best fit: y \
="\[InvisibleSpace]0.007110932948529668`\[InvisibleSpace]"* x"\),
      SequenceForm[ 
      "Equation of best fit: y =", 0.0071109329485296684, "* x"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of top worst fit: y = \
"\[InvisibleSpace]0.007199822076873665`\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of top worst fit: y = ", 0.0071998220768736652, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of bottom worst fit: y = \
"\[InvisibleSpace]0.0070220438201856715`\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of bottom worst fit: y = ", 0.0070220438201856715, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Certainty Measure \!\(R\^2\): \
"\[InvisibleSpace]0.9999678276768436`\),
      SequenceForm[ "Certainty Measure \!\(R\^2\): ", 0.99996782767684356],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - \
1\)\): "\[InvisibleSpace]0.00406397428356149`\),
      SequenceForm[ 
      "Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 1\)\): ", 
        0.00406397428356149],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[\[IndentingNewLine]ErrorListPlot[
          dataset], \[IndentingNewLine]Plot[{b\ x + a} /. parameter // 
            Evaluate, {x, 0, Max[Column[dataset, 1]]}, 
          PlotStyle \[Rule] {Dashing[{0}]}], 
        Plot[{\((b + \[CapitalDelta]b)\) 
                    x + \((a + \[CapitalDelta]a)\), \((b - \
\[CapitalDelta]b)\) x + \((a - \[CapitalDelta]a)\)} /. parameter // 
            Evaluate, {x, 0, 
            Max[Column[dataset, 
                1]]}, \[IndentingNewLine]PlotStyle \[Rule] \
{Dashing[{0.01}]}], ImageSize \[Rule] 700, PlotLabel \[Rule] "\<dataset\>", 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 700 432.624 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 7.61945e-05 0.0147151 0.00635641 [
[.1762 .00222 -12 -9 ]
[.1762 .00222 12 0 ]
[.32859 .00222 -12 -9 ]
[.32859 .00222 12 0 ]
[.48098 .00222 -12 -9 ]
[.48098 .00222 12 0 ]
[.63337 .00222 -12 -9 ]
[.63337 .00222 12 0 ]
[.78575 .00222 -15 -9 ]
[.78575 .00222 15 0 ]
[.93814 .00222 -15 -9 ]
[.93814 .00222 15 0 ]
[1.025 .01472 0 -4.90625 ]
[1.025 .01472 10 4.90625 ]
[.01131 .14184 -12 -4.5 ]
[.01131 .14184 0 4.5 ]
[.01131 .26897 -12 -4.5 ]
[.01131 .26897 0 4.5 ]
[.01131 .3961 -12 -4.5 ]
[.01131 .3961 0 4.5 ]
[.01131 .52323 -12 -4.5 ]
[.01131 .52323 0 4.5 ]
[.02381 .64303 -5.03125 0 ]
[.02381 .64303 5.03125 9.8125 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1762 .01472 m
.1762 .02097 L
s
[(2000)] .1762 .00222 0 1 Mshowa
.32859 .01472 m
.32859 .02097 L
s
[(4000)] .32859 .00222 0 1 Mshowa
.48098 .01472 m
.48098 .02097 L
s
[(6000)] .48098 .00222 0 1 Mshowa
.63337 .01472 m
.63337 .02097 L
s
[(8000)] .63337 .00222 0 1 Mshowa
.78575 .01472 m
.78575 .02097 L
s
[(10000)] .78575 .00222 0 1 Mshowa
.93814 .01472 m
.93814 .02097 L
s
[(12000)] .93814 .00222 0 1 Mshowa
.125 Mabswid
.06191 .01472 m
.06191 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.2143 .01472 m
.2143 .01847 L
s
.25239 .01472 m
.25239 .01847 L
s
.29049 .01472 m
.29049 .01847 L
s
.36668 .01472 m
.36668 .01847 L
s
.40478 .01472 m
.40478 .01847 L
s
.44288 .01472 m
.44288 .01847 L
s
.51907 .01472 m
.51907 .01847 L
s
.55717 .01472 m
.55717 .01847 L
s
.59527 .01472 m
.59527 .01847 L
s
.67146 .01472 m
.67146 .01847 L
s
.70956 .01472 m
.70956 .01847 L
s
.74766 .01472 m
.74766 .01847 L
s
.82385 .01472 m
.82385 .01847 L
s
.86195 .01472 m
.86195 .01847 L
s
.90005 .01472 m
.90005 .01847 L
s
.97624 .01472 m
.97624 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .14184 m
.03006 .14184 L
s
[(20)] .01131 .14184 1 0 Mshowa
.02381 .26897 m
.03006 .26897 L
s
[(40)] .01131 .26897 1 0 Mshowa
.02381 .3961 m
.03006 .3961 L
s
[(60)] .01131 .3961 1 0 Mshowa
.02381 .52323 m
.03006 .52323 L
s
[(80)] .01131 .52323 1 0 Mshowa
.125 Mabswid
.02381 .0465 m
.02756 .0465 L
s
.02381 .07828 m
.02756 .07828 L
s
.02381 .11006 m
.02756 .11006 L
s
.02381 .17363 m
.02756 .17363 L
s
.02381 .20541 m
.02756 .20541 L
s
.02381 .23719 m
.02756 .23719 L
s
.02381 .30075 m
.02756 .30075 L
s
.02381 .33254 m
.02756 .33254 L
s
.02381 .36432 m
.02756 .36432 L
s
.02381 .42788 m
.02756 .42788 L
s
.02381 .45966 m
.02756 .45966 L
s
.02381 .49145 m
.02756 .49145 L
s
.02381 .55501 m
.02756 .55501 L
s
.02381 .58679 m
.02756 .58679 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66.0312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dataset) show
105.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.13255 .07319 m
.13255 .08464 L
s
.015 w
.13255 .07891 Mdot
.002 w
.21316 .1196 m
.21316 .13358 L
s
.015 w
.21316 .12659 Mdot
.002 w
.30315 .17108 m
.30315 .19015 L
s
.015 w
.30315 .18062 Mdot
.002 w
.35564 .20096 m
.35564 .22257 L
s
.015 w
.35564 .21176 Mdot
.002 w
.40814 .23147 m
.40814 .25562 L
s
.015 w
.40814 .24355 Mdot
.002 w
.46813 .26579 m
.46813 .29249 L
s
.015 w
.46813 .27914 Mdot
.002 w
.5075 .28804 m
.5075 .31728 L
s
.015 w
.5075 .30266 Mdot
.002 w
.54874 .31156 m
.54874 .34334 L
s
.015 w
.54874 .32745 Mdot
.002 w
.60124 .3408 m
.60124 .37512 L
s
.015 w
.60124 .35796 Mdot
.002 w
.65561 .37195 m
.65561 .40881 L
s
.015 w
.65561 .39038 Mdot
.002 w
.6856 .38847 m
.6856 .42661 L
s
.015 w
.6856 .40754 Mdot
.002 w
.72872 .41263 m
.72872 .45331 L
s
.015 w
.72872 .43297 Mdot
.002 w
.78871 .44695 m
.78871 .49017 L
s
.015 w
.78871 .46856 Mdot
.002 w
.82808 .46856 m
.82808 .51433 L
s
.015 w
.82808 .49145 Mdot
.002 w
.86933 .49017 m
.86933 .53848 L
s
.015 w
.86933 .51433 Mdot
.002 w
.91245 .51433 m
.91245 .56391 L
s
.015 w
.91245 .53912 Mdot
.002 w
.97619 .54993 m
.97619 .60332 L
s
.015 w
.97619 .57662 Mdot
.5 Mabswid
.02381 .01472 m
.06244 .03763 L
.10458 .06263 L
.14415 .0861 L
.18221 .10868 L
.22272 .13271 L
.26171 .15584 L
.30316 .18043 L
.34309 .20412 L
.3815 .2269 L
.42237 .25115 L
.46172 .27449 L
.49955 .29693 L
.53984 .32083 L
.57861 .34383 L
.61984 .36829 L
.65954 .39184 L
.69774 .4145 L
.73838 .43861 L
.77751 .46183 L
.81909 .48649 L
.85916 .51026 L
.89771 .53313 L
.93871 .55745 L
.97619 .57969 L
s
[ .01 ] 0 setdash
.02381 .01472 m
.06244 .03792 L
.10458 .06323 L
.14415 .087 L
.18221 .10985 L
.22272 .13419 L
.26171 .15761 L
.30316 .1825 L
.34309 .20648 L
.3815 .22956 L
.42237 .2541 L
.46172 .27774 L
.49955 .30046 L
.53984 .32466 L
.57861 .34795 L
.61984 .37271 L
.65954 .39656 L
.69774 .4195 L
.73838 .44391 L
.77751 .46741 L
.81909 .49239 L
.85916 .51646 L
.89771 .53961 L
.93871 .56424 L
.97619 .58675 L
s
.02381 .01472 m
.06244 .03735 L
.10458 .06203 L
.14415 .08521 L
.18221 .10751 L
.22272 .13124 L
.26171 .15408 L
.30316 .17836 L
.34309 .20175 L
.3815 .22425 L
.42237 .24819 L
.46172 .27124 L
.49955 .29341 L
.53984 .31701 L
.57861 .33972 L
.61984 .36387 L
.65954 .38713 L
.69774 .4095 L
.73838 .43331 L
.77751 .45624 L
.81909 .4806 L
.85916 .50407 L
.89771 .52665 L
.93871 .55067 L
.97619 .57262 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{700, 432.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:l0001/2000`400?l00000o`00003oo`3ooooo
0?oookh0oooo003o0?ooool0oooo_P3oool007L0oooo100000030?ooo`800000103oool2000000@0
oooo0P00001?0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool2000004h0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001>0?ooo`800000103oool2000000@0
oooo0P0000040?ooo`800000BP3oool4000000<0oooo0P0000040?ooo`800000103oool2000000@0
oooo0P0000180?ooo`@000000P3oool4000000<0oooo0P0000040?ooo`800000103oool200000480
oooo001g0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000004h0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`1:0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000004`0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000B`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0A`3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000440oooo001h0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000004/0oooo1@0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001<0?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000004`0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000B`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000440oooo001i0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0B@3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001<0?ooo`<000000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000C@3oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000004/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo03l0oooo001j0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000C03oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001<0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000004/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0o0?ooo`00803oool00`000000oooo0?ooo`1D0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000004d0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00001<0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000004`0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000B@3oool3000000<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool00000A`3oool3000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000@@3oool00200oooo
00<000000?ooo`3oool0E@3oool2000000@0oooo0P0000040?ooo`800000103oool2000004l0oooo
00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`800000CP3oool3000000<0oooo
0P0000040?ooo`800000103oool2000004h0oooo0P0000040?ooo`800000103oool2000000@0oooo
0P00001<0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool2000000@0oooo
0P00001:0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool2000000@0oooo
0P0000120?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0ooooV`3oool00200oooo00<00000
0?ooo`3oool0o`3ooooo0?oooi/0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3ooonK0?oo
o`00803oool00`000000oooo0?ooo`3o0?ooool0ooooV`3oool00200oooo00<000000?ooo`3oool0
o`3ooooo0?oooi/0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3ooonK0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooool0ooooV`3oool00200oooo00<000000?ooo`3oool0o`3ooooo0?oo
ohH0oooo0P0000000`3oool000000000000@0?ooo`00403ooooo00000?l00000Q`00000C0?ooo`03
0000003oool000000140oooo000P0?ooo`<000005@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0100oooo000P0?ooo`030000003oool0oooo008000004`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool000000140oooo000P0?ooo`040000003oool0oooo0?ooo`800000G03o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G`3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0=`3o
ool2000000030?ooo`00000000000100oooo000P0?ooo`030000003oool0oooo00<0oooo0P00001J
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1<
0?ooo`00803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooo`3ooonC0?oo
o`00803oool00`000000oooo0?ooo`060?ooo`<00000o`3ooooo0?oooi80oooo000P0?ooo`030000
003oool0oooo00P0oooo0P00003o0?ooool0ooooT@3oool00200oooo00<000000?ooo`3oool02@3o
ool300000?l0ooooo`3ooon?0?ooo`00803oool00`000000oooo0?ooo`0;0?ooo`800000o`3ooooo
0?ooohh0oooo000P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oh/0oooo000P0?ooo`030000003oool0oooo00h0oooo0P00003o0?ooool0ooooR`3oool00200oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooool0ooooR03oool00200oooo00<0
00000?ooo`3oool04@3oool300000?l0ooooo`3ooon70?ooo`00803oool00`000000oooo0?ooo`0C
0?ooo`800000o`3ooooo0?ooohH0oooo000P0?ooo`030000003oool0oooo01D0oooo0P00003o0?oo
ool0ooooQ03oool00200oooo00<000000?ooo`3oool05P3oool300000?l0ooooo`3ooon20?ooo`00
803oool00`000000oooo0?ooo`0H0?ooo`800000o`3ooooo0?oooh40oooo000P0?ooo`030000003o
ool0oooo01X0oooo0P00003o0?ooool0ooooO`3oool00200oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`3o0?ooool0ooooO03oool00200oooo0`00000M0?ooo`800000o`3ooooo0?oo
og`0oooo000P0?ooo`030000003oool0oooo01l0oooo0P00003o0?ooool0ooooNP3oool00200oooo
00<000000?ooo`3oool08@3oool200000?l0ooooo`3ooomh0?ooo`00803oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo0?l0ooooo`3ooome0?ooo`00803oool00`000000oooo0?ooo`0T
0?ooo`800000o`3ooooo0?ooogD0oooo000P0?ooo`030000003oool0oooo02H0oooo0P00003o0?oo
ool0ooooL`3oool00200oooo00<000000?ooo`3oool0:03oool200000?l0ooooo`3oooma0?ooo`00
803oool00`000000oooo0?ooo`0Z0?ooo`800000o`3ooooo0?ooofl0oooo000P0?ooo`030000003o
ool0oooo02/0oooo0`00003o0?ooool0ooooK@3oool00200oooo00<000000?ooo`3oool0;@3oool3
00000?l0ooooo`3ooom[0?ooo`00803oool00`000000oooo0?ooo`0^0?ooo`<00000o`3ooooo0?oo
ofX0oooo000P0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0o`3ooooo0?ooofL0
oooo000P0?ooo`030000003oool0oooo0380oooo0`00003o0?ooool0ooooIP3oool00200oooo00<0
00000?ooo`3oool0=03oool300000?l0ooooo`3ooomT0?ooo`00803oool00`000000oooo0?ooo`0e
0?ooo`<00000o`3ooooo0?ooof<0oooo000P0?ooo`030000003oool0oooo03L0oooo0`00003o0?oo
ool0ooooH@3oool00200oooo00<000000?ooo`3oool0>@3oool200000?l0ooooo`3ooomP0?ooo`00
803oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`00803o
ool00`000000oooo0?ooo`0l0?ooo`8000000P3oool600000?l0ooooo`3ooomE0?ooo`00803oool0
0`000000oooo0?ooo`0n0?ooo`T00000o`3ooooo0?oooe@0oooo000P0?ooo`030000003oool0oooo
03l0oooo2000003o0?ooool0ooooE03oool00200oooo0`00000o0?ooo`P00000o`3ooooo0?oooe@0
oooo000P0?ooo`030000003oool0oooo03l0oooo2000003o0?ooool0ooooE03oool00200oooo00<0
00000?ooo`3oool0?`3oool800000?l0ooooo`3ooomD0?ooo`00803oool00`000000oooo0?ooo`0o
0?ooo`T00000o`3ooooo0?oooe<0oooo000P0?ooo`030000003oool0oooo0400oooo1P0000020?oo
o`800000o`3ooooo0?oooe40oooo000P0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodh0oooo000P0?ooo`030000003oool0oooo04/0oooo0P00003o0?ooool0oooo
CP3oool00200oooo00<000000?ooo`3oool0C03oool300000?l0ooooo`3ooom<0?ooo`00803oool0
0`000000oooo0?ooo`1>0?ooo`<00000o`3ooooo0?ooodX0oooo000P0?ooo`030000003oool0oooo
04l0oooo00@000000?ooo`0000000000o`3ooooo0?ooodP0oooo000P0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0o`3ooooo0?ooodD0oooo000P0?ooo`030000003oool0oooo05@0
oooo0P00003o0?ooool0ooooA@3oool00200oooo00<000000?ooo`3oool0E@3oool300000?l0oooo
o`3ooom30?ooo`00803oool00`000000oooo0?ooo`1F0?ooo`@00000o`3ooooo0?oood40oooo000P
0?ooo`030000003oool0oooo05P0oooo1000003o0?ooool0oooo?`3oool00200oooo00<000000?oo
o`3oool0FP3oool300000?l0ooooo`3oooln0?ooo`00803oool00`000000oooo0?ooo`1M0?ooo`80
0000o`3ooooo0?oooc`0oooo000P0?ooo`030000003oool0oooo05l0oooo0P00003o0?ooool0oooo
>P3oool00200oooo00<000000?ooo`3oool0H@3oool200000?l0ooooo`3ooolh0?ooo`00803oool0
0`000000oooo0?ooo`1P0?ooo`@00000o`3ooooo0?ooocL0oooo000P0?ooo`<00000HP3oool40000
0?l0ooooo`3ooole0?ooo`00803oool00`000000oooo0?ooo`1T0?ooo`040000003oool000000000
0?l0ooooo`3ooolc0?ooo`00803oool00`000000oooo0?ooo`1U0?ooo`040000003oool0oooo0000
0?l0ooooo`3ooolb0?ooo`00803oool00`000000oooo0?ooo`1Y0?ooo`800000o`3ooooo0?oooc00
oooo000P0?ooo`030000003oool0oooo06/0oooo0P00003o0?ooool0oooo;P3oool00200oooo00<0
00000?ooo`3oool0J`3oool400000?l0ooooo`3oool/0?ooo`00803oool00`000000oooo0?ooo`1/
0?ooo`030000003oool00000008000001P3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool0
0200oooo00<000000?ooo`3oool0K@3oool2000000030?ooo`00000000000080oooo1P00003o0?oo
ool0oooo8@3oool00200oooo00<000000?ooo`3oool0K`3oool00`000000oooo0000000900000?l0
ooooo`3ooolP0?ooo`00803oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00P00000
o`3ooooo0?ooob00oooo000P0?ooo`030000003oool0oooo07<0oooo2000003o0?ooool0oooo803o
ool00200oooo00<000000?ooo`3oool0L`3oool800000?l0ooooo`3ooolP0?ooo`00803oool00`00
0000oooo0?ooo`1c0?ooo`P00000o`3ooooo0?ooob00oooo000P0?ooo`030000003oool0oooo07<0
oooo2@00003o0?ooool0oooo7`3oool00200oooo00<000000?ooo`3oool0M03oool900000?l0oooo
o`3ooolN0?ooo`00803oool00`000000oooo0?ooo`1g0?ooo`070000003oool0oooo0?ooo`000000
oooo0000003o0?ooool0oooo7@3oool00200oooo00<000000?ooo`3oool0OP3oool200000?l0oooo
o`3ooolK0?ooo`00803oool00`000000oooo0?ooo`200?ooo`<00000o`3ooooo0?oooaP0oooo000P
0?ooo`030000003oool0oooo0880oooo0`00003o0?ooool0oooo5P3oool000`0oooo100000030?oo
o`8000002`3oool00`000000oooo0?ooo`210?ooo`030000003oool0000000<00000o`3ooooo0?oo
oa@0oooo000<0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`220?ooo`80000000@0oooo0000000000000000o`3ooooo0?oooa<0oooo000=0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000002P3oool500000880oooo0P000000
0`3oool000000?ooo`3o0?ooool0oooo4P3oool000h0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0QP3oool400000?l0ooooo`3ooolA
0?ooo`003`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0RP3oool200000?l0ooooo`3oool?0?ooo`00303oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0S03oool200000?l0ooooo`3o
ool=0?ooo`003@3oool2000000@0oooo0P00000;0?ooo`030000003oool0oooo08`0oooo1000003o
0?ooool0oooo2`3oool00200oooo00<000000?ooo`3oool0S@3oool500000?l0ooooo`3oool90?oo
o`00803oool00`000000oooo0?ooo`2?0?ooo`030000003oool0000000800000o`3ooooo0?ooo`L0
oooo000P0?ooo`030000003oool0oooo0900oooo1000003o0?ooool0oooo1`3oool00200oooo00<0
00000?ooo`3oool0TP3oool010000000oooo00000000003o0?ooool0oooo1@3oool00200oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0000003o0?ooool0oooo0P3oool00200oooo00<00000
0?ooo`3oool0U`3oool400000?l0ooooo`3oool00200oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0000000300000?l0ooooo@3oool00200oooo00<000000?ooo`3oool0V03oool200000003
0?ooo`000000oooo00800000o`3ooook0?ooo`00803oool00`000000oooo0?ooo`2J0?ooo`@00000
o`3ooool0?ooo`00803oool00`000000oooo0?ooo`2L0?ooo`@00000o`3ooooj0?ooo`00803oool0
0`000000oooo0?ooo`2P0?ooo`030000003oool0oooo0?l0oooom`3oool00200oooo00<000000?oo
o`3oool0X@3oool300000?l0oooomP3oool00200oooo00<000000?ooo`3oool0XP3oool400000?l0
oooom03oool00200oooo00<000000?ooo`3oool0X`3oool500000?l0oooolP3oool00200oooo00<0
00000?ooo`3oool0Y@3oool00`000000oooo00000002000000H0oooo00<000000?ooo`3oool0o`3o
oooW0?ooo`00803oool300000:H0oooo100000060?ooo`030000003oool0oooo0?l0ooooi`3oool0
0200oooo00<000000?ooo`3oool0Z03oool010000000oooo0000000000020?ooo`H00000o`3ooooV
0?ooo`00803oool00`000000oooo0?ooo`2/0?ooo`T00000o`3ooooU0?ooo`00803oool00`000000
oooo0?ooo`2]0?ooo`P00000o`3ooooU0?ooo`00803oool00`000000oooo0?ooo`2]0?ooo`P00000
o`3ooooU0?ooo`00803oool00`000000oooo0?ooo`2]0?ooo`P00000o`3ooooU0?ooo`00803oool0
0`000000oooo0?ooo`2]0?ooo`P00000o`3ooooU0?ooo`00803oool00`000000oooo0?ooo`2]0?oo
o`T00000o`3ooooT0?ooo`00803oool00`000000oooo0?ooo`2^0?ooo`H000000P3oool00`000000
oooo0?ooo`3o0?ooon40oooo000P0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
103oool300000?l0ooooh03oool00200oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`060?ooo`<00000o`3ooooN0?ooo`00803oool00`000000oooo0?ooo`2`0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`00003o0?ooom`0oooo000P0?ooo`030000003oool0oooo
0;T0oooo0P0000000`3oool000000000000200000?l0oooofP3oool00200oooo00<000000?ooo`3o
ool0^`3oool2000000030?ooo`00000000000?l0oooofP3oool00200oooo00<000000?ooo`3oool0
_@3oool2000000030?ooo`000000oooo0?l0oooof03oool00200oooo00<000000?ooo`3oool0`@3o
ool200000080oooo00<000000?ooo`3oool0o`3ooooB0?ooo`00803oool00`000000oooo0?ooo`33
0?ooo`80000000<0oooo000000000000o`3ooooB0?ooo`00803oool00`000000oooo0?ooo`330?oo
o`030000003oool000000080oooo0P00003o0?ooom00oooo000P0?ooo`030000003oool0oooo0<@0
oooo100000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oooo50?ooo`00
803oool00`000000oooo0?ooo`360?ooo`040000003oool00000000000P0oooo00<000000?ooo`3o
ool0o`3oooo50?ooo`00803oool00`000000oooo0?ooo`370?ooo`80000000<0oooo0000003oool0
1P3oool00`000000oooo0?ooo`3o0?ooolD0oooo000P0?ooo`<00000b@3oool010000000oooo0000
000000030?ooo`H00000o`3oooo40?ooo`00803oool00`000000oooo0?ooo`3=0?ooo`X00000o`3o
ooo30?ooo`00803oool00`000000oooo0?ooo`3?0?ooo`P00000o`3oooo30?ooo`00803oool00`00
0000oooo0?ooo`3>0?ooo`T00000o`3oooo30?ooo`00803oool00`000000oooo0?ooo`3?0?ooo`P0
0000o`3oooo30?ooo`00803oool00`000000oooo0?ooo`3?0?ooo`P00000o`3oooo30?ooo`00803o
ool00`000000oooo0?ooo`3?0?ooo`P00000o`3oooo30?ooo`00803oool00`000000oooo0?ooo`3@
0?ooo`H0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`3o0?oook`0oooo000P0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020000
0?l0oooo_03oool00200oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`80
00000P3oool200000?l0oooo^P3oool00200oooo00<000000?ooo`3oool0dP3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`3o0?oookL0oooo
000P0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool200000080oooo00<0
00000?ooo`3oool0o`3oooni0?ooo`00803oool00`000000oooo0?ooo`3L0?ooo`80000000<0oooo
000000000000o`3oooni0?ooo`00803oool00`000000oooo0?ooo`3N0?ooo`80000000<0oooo0000
00000000o`3ooong0?ooo`00803oool00`000000oooo0?ooo`3S0?ooo`040000003oool0oooo0000
0?l0oooo/`3oool00200oooo00<000000?ooo`3oool0i03oool2000000030?ooo`00000000000?l0
oooo/@3oool00200oooo00<000000?ooo`3oool0i03oool01@000000oooo000000000000oooo0080
0000o`3ooon_0?ooo`00803oool00`000000oooo0?ooo`3U0?ooo`80000000@0oooo000000000000
oooo0P0000070?ooo`030000003oool0oooo0?l0ooooX`3oool00200oooo00<000000?ooo`3oool0
i`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0?l0ooooX`3oool00200oooo
00<000000?ooo`3oool0j03oool2000000030?ooo`000000000000L0oooo00<000000?ooo`3oool0
o`3ooonS0?ooo`00803oool300000>X0oooo00<000000?ooo`3oool00P0000020?ooo`040000003o
ool0oooo00000?l0ooooY@3oool00200oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?oo
o`0600000?l0ooooXP3oool00200oooo00<000000?ooo`3oool0l03oool900000?l0ooooX@3oool0
0200oooo00<000000?ooo`3oool0k`3oool00`000000oooo0000000700000?l0ooooX@3oool00200
oooo00<000000?ooo`3oool0l03oool900000?l0ooooX@3oool00200oooo00<000000?ooo`3oool0
l@3oool800000?l0ooooX@3oool00200oooo00<000000?ooo`3oool0l@3oool800000?l0ooooX@3o
ool00200oooo00<000000?ooo`3oool0l@3oool:000000030?ooo`00000000000?l0ooooW03oool0
0200oooo00<000000?ooo`3oool0lP3oool6000000<0oooo0P0000000`3oool000000000003o0?oo
oiX0oooo000P0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0200000?l0ooooV03oool00200oooo00<000000?ooo`3oool0m03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`3o0?oooiD0oooo
000P0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool01@3oool200000080oooo0P00
003o0?oooiP0oooo000P0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool01`3oool2
00000080oooo0P00003o0?oooiH0oooo000P0?ooo`030000003oool0oooo0?l0oooo0@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0o`3ooon@0?ooo`00803oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo0P0000000`3oool000000000003o0?oooi00oooo000P0?ooo`03
0000003oool0oooo0?l0oooo203oool2000000030?ooo`00000000000?l0ooooSP3oool00200oooo
00<000000?ooo`3oool0o`3oool70?ooo`040000003oool0oooo00000080oooo0P00003o0?oooh`0
oooo000P0?ooo`030000003oool0oooo0?l0oooo203oool2000000030?ooo`00000000000?l0oooo
SP3oool00200oooo00<000000?ooo`3oool0o`3oool:0?ooo`80000000<0oooo000000000000o`3o
oon<0?ooo`003P3oool00`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`3o
0?ooo``0oooo00<000000?ooo`3oool00P00000;0?ooo`030000003oool0oooo0?l0ooooO03oool0
00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0o`3ooolA0?ooo`040000003oool00000000000L0oooo00<000000?ooo`3oool0o`3o
ooml0?ooo`002`3oool500000080oooo00@000000?ooo`3oool000002P3oool500000?l0oooo403o
ool2000000030?ooo`000000000000D0oooo00<000000?ooo`3oool0o`3oooml0?ooo`002`3oool0
10000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
o`3ooolD0?ooo`80000000<0oooo0000000000000`3oool00`000000oooo0?ooo`3o0?ooog`0oooo
000<0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`3o0?oooa80oooo00@000000?ooo`3oool0oooo0P0000001@3oool000000?ooo`3oool00000
0?l0ooooOP3oool000d0oooo0P0000030?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool0o`3ooolC0?ooo`8000000`3oool700000?l0ooooO03oool000h0oooo00<000000?ooo`3o
ool00P3oool2000000/0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`80000000<0oooo00000000
00001P00003o0?ooog/0oooo000P0?ooo`030000003oool0oooo0?l0oooo5`3oool900000?l0oooo
N`3oool00200oooo00<000000?ooo`3oool0o`3ooolH0?ooo`T00000o`3ooomj0?ooo`00803oool0
0`000000oooo0?ooo`3o0?oooaP0oooo200000000`3oool000000000003o0?ooogP0oooo000P0?oo
o`030000003oool0oooo0?l0oooo603oool900000080oooo00<000000?ooo`3oool0o`3ooome0?oo
o`00803oool00`000000oooo0?ooo`3o0?oooaP0oooo200000001@3oool000000000003oool00000
0?l0ooooMP3oool00200oooo00<000000?ooo`3oool0o`3ooolI0?ooo`P000000P3oool00`000000
oooo0?ooo`3o0?ooogD0oooo000P0?ooo`030000003oool0oooo0?l0oooo703oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00800000o`3ooome0?ooo`00803oool00`000000oooo0?oo
o`3o0?oooa`0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool200000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooof<0oooo000P0?ooo`030000003o
ool0oooo0?l0oooo703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00800000203o
ool00`000000oooo0?ooo`3o0?ooof<0oooo000P0?ooo`030000003oool0oooo0?l0oooo703oool0
0`000000oooo0?ooo`0:0?ooo`8000000P3oool2000000H0oooo00<000000?ooo`3oool0o`3ooomS
0?ooo`00803oool00`000000oooo0?ooo`3o0?oooa`0oooo00<000000?ooo`3oool02@3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomS
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooobT0oooo0P0000000`3oool00000000000070?oo
o`030000003oool0oooo0?l0ooooH`3oool00200oooo00<000000?ooo`3oool0o`3oool[0?ooo`80
000000<0oooo0000000000001@3oool00`000000oooo0?ooo`3o0?ooof<0oooo000P0?ooo`030000
003oool0oooo0?l0oooo;@3oool010000000oooo0?ooo`0000020?ooo`H00000o`3ooomR0?ooo`00
803oool00`000000oooo0?ooo`3o0?oooc40oooo2@00003o0?ooof40oooo000P0?ooo`<00000o`3o
oolb0?ooo`P00000o`3ooomQ0?ooo`00803oool00`000000oooo0?ooo`3o0?oooc80oooo2000003o
0?ooof40oooo000P0?ooo`030000003oool0oooo0?l0oooo<P3oool900000?l0ooooH03oool00200
oooo00<000000?ooo`3oool0o`3ooolb0?ooo`P00000o`3ooomQ0?ooo`00803oool00`000000oooo
0?ooo`3o0?oooc80oooo2P00003o0?oooel0oooo000P0?ooo`030000003oool0oooo0?l0oooo<`3o
ool6000000<0oooo00D000000?ooo`3oool0oooo0000003o0?oooeX0oooo000P0?ooo`030000003o
ool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`050?ooo`8000000P3oool200000?l0ooooF03o
ool00200oooo00<000000?ooo`3oool0o`3ooole0?ooo`030000003oool0oooo00L0oooo0P000002
0?ooo`8000002`3oool00`000000oooo0?ooo`3o0?ooodP0oooo000P0?ooo`030000003oool0oooo
0?l0oooo=@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo008000000P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooB03oool00200oooo00<000000?ooo`3o
ool0o`3ooole0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`030000003oool0oooo0?l0ooooB03oool00200oooo00<000000?ooo`3oool0o`3ooole0?ooo`03
0000003oool0oooo00P0oooo0P0000020?ooo`8000002P3oool00`000000oooo0?ooo`3o0?ooodP0
oooo000P0?ooo`030000003oool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0
ooooB03oool00200oooo00<000000?ooo`3oool0o`3ooom30?ooo`030000003oool0oooo0080oooo
0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000P0?ooo`030000003o
ool0oooo0?l0ooooBP3oool01`000000oooo0?ooo`3oool000000?ooo`000000o`3ooom:0?ooo`00
803oool00`000000oooo0?ooo`3o0?oood/0oooo2000003o0?ooodP0oooo000P0?ooo`030000003o
ool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0800000?l0ooooA`3oool00200oooo00<00000
0?ooo`3oool0o`3ooom:0?ooo`030000003oool0000000L00000o`3ooom70?ooo`00803oool00`00
0000oooo0?ooo`3o0?oood/0oooo2@00003o0?ooodL0oooo000P0?ooo`030000003oool0oooo0?l0
ooooC03oool800000080oooo00<000000?ooo`3oool0o`3ooom20?ooo`00803oool00`000000oooo
0?ooo`3o0?oood`0oooo2@0000020?ooo`800000o`3ooom20?ooo`00803oool00`000000oooo0?oo
o`3o0?oood`0oooo200000000`3oool00000000000020?ooo`800000o`3ooom00?ooo`00803oool3
00000?l0ooooC@3oool6000000@0oooo0P0000020?ooo`800000o`3oooln0?ooo`00803oool00`00
0000oooo0?ooo`3o0?oooe00oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0?l0oooo?`3oool00200oooo00<000000?ooo`3oool0o`3ooom@0?ooo`030000003oool0oooo
0080oooo0P0000030?ooo`800000o`3ooolo0?ooo`00803oool00`000000oooo0?ooo`3o0?oooe00
oooo00<000000?ooo`3oool0103oool2000000<0oooo0P0000030?ooo`030000003oool0oooo0?l0
oooo=`3oool00200oooo00<000000?ooo`3oool0o`3ooom@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000?l0oooo=`3oool00200oooo
00<000000?ooo`3oool0o`3ooom@0?ooo`030000003oool0oooo00`0oooo0P0000030?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`00803oool00`000000oooo0?oo
o`3o0?oooe00oooo00<000000?ooo`3oool03P3oool200000080oooo0P00000;0?ooo`030000003o
ool0oooo0?l0oooo9P3oool00200oooo00<000000?ooo`3oool0o`3ooom@0?ooo`030000003oool0
oooo00`0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0o`3ooolV0?ooo`00803oool00`000000oooo0?ooo`3o0?ooof00oooo00@00000
0?ooo`3oool0oooo0P00000<0?ooo`030000003oool0oooo0?l0oooo9P3oool00200oooo00<00000
0?ooo`3oool0o`3ooomQ0?ooo`8000000`3oool2000000X0oooo00<000000?ooo`3oool0o`3ooolV
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooof<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0o`3ooolV0?ooo`00803oool00`00
0000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000030?oo
o`030000003oool0oooo0?l0oooo9P3oool00200oooo00<000000?ooo`3oool0o`3ooom[0?ooo`80
00000P3oool600000?l0oooo9P3oool00200oooo00<000000?ooo`3oool0o`3ooom]0?ooo`T00000
o`3ooolU0?ooo`00803oool00`000000oooo0?ooo`3o0?ooofX0oooo00@000000?ooo`3oool0oooo
2000003o0?ooobD0oooo000P0?ooo`030000003oool0oooo0?l0ooooJ`3oool2000000030?ooo`00
0000000000H00000o`3ooolU0?ooo`00803oool00`000000oooo0?ooo`3o0?ooofd0oooo2@000000
0`3oool000000?ooo`3o0?ooob80oooo000P0?ooo`030000003oool0oooo0?l0ooooKP3oool80000
0080oooo0P00003o0?ooob40oooo000P0?ooo`030000003oool0oooo0?l0ooooKP3oool9000000<0
oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00803oool00`000000oooo0?ooo`3o0?ooofl0oooo
1P0000020?ooo`8000000P3oool200000?l0oooo7P3oool00200oooo0`00003o0?ooog80oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000?l0oooo7@3oool00200oooo
00<000000?ooo`3oool0o`3ooomb0?ooo`040000003oool0oooo0?ooo`8000000P3oool200000?l0
oooo7`3oool00200oooo00<000000?ooo`3oool0o`3ooomb0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool0oooo0P00003o0?oooad0oooo000P0?ooo`030000003oool0oooo0?l0oooo
LP3oool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?l0oooo5@3oool00200oooo00<000000?ooo`3oool0o`3ooomb0?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`800000o`3ooolE0?ooo`00803o
ool00`000000oooo0?ooo`3o0?ooog80oooo00<000000?ooo`3oool0303oool2000000<0oooo0P00
000=0?ooo`030000003oool0oooo0?l0oooo0`3oool00200oooo00<000000?ooo`3oool0o`3ooomb
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0?l0oooo0`3oool00200oooo00<000000?ooo`3oool0o`3ooomb0?oo
o`030000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0P00000?0?ooo`030000003oool0
oooo0?l0oooo0`3oool00200oooo00<000000?ooo`3oool0o`3ooon10?ooo`8000000`3oool20000
00d0oooo00<000000?ooo`3oool0o`3oool30?ooo`00803oool00`000000oooo0?ooo`3o0?oooh<0
oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3o0?ooo`<0oooo000P0?ooo`030000003oool0oooo0?l0ooooQ@3oool200000080oooo
0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool30?ooo`00803o
ool00`000000oooo0?ooo`3o0?oooh/0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo000P0?ooo`030000003oool0oooo0?l0ooooS@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000?l0oooo1@3oool00200oooo00<000000?ooo`3oool0o`3ooon>
0?ooo`8000000P3oool600000?l0oooo0`3oool00200oooo00<000000?ooo`3oool0o`3ooon;0?oo
o`030000003oool0oooo0080oooo2@00003o0?ooo`80oooo000P0?ooo`030000003oool0oooo0?l0
ooooS03oool2000000<0oooo2000003o0?ooo`80oooo000P0?ooo`030000003oool0oooo0?l0oooo
SP3oool2000000030?ooo`000000000000L000003P3oool00`000000oooo0?ooo`3_0?ooo`00803o
ool00`000000oooo0?ooo`3o0?oooi00oooo2@0000000`3oool000000000000<0?ooo`030000003o
ool0oooo0>l0oooo000P0?ooo`030000003oool0oooo0?l0ooooT@3oool8000000<0oooo0P00000:
0?ooo`030000003oool0oooo0>l0oooo000=0?ooo`800000103oool2000000/0oooo00<000000?oo
o`3oool0o`3ooonA0?ooo`T00000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0>l0oooo000<0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`3o0?oooi80oooo1P0000020?ooo`800000303oool00`000000oooo0?ooo`3_
0?ooo`00303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo1@00
003o0?oooi<0oooo00<000000?ooo`000000103oool2000000X0oooo00<000000?ooo`3oool0k`3o
ool000`0oooo0`0000030?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3o
oonE0?ooo`030000003oool0oooo00800000103oool2000000@0oooo00D000000?ooo`3oool0oooo
0000003a0?ooo`00303oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool0o`3ooonE0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000
003oool0oooo0080oooo0P0000000`3oool000000?ooo`3`0?ooo`00303oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000000<0oooo1P00003^0?ooo`003@3o
ool3000000<0oooo0P00000;0?ooo`030000003oool0oooo0?l0ooooU@3oool00`000000oooo0?oo
o`0;0?ooo`X00000k@3oool00200oooo00<000000?ooo`3oool0o`3ooonE0?ooo`030000003oool0
oooo00d0oooo2000003]0?ooo`00803oool00`000000oooo0?ooo`3o0?oooiD0oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`3oool800000>d0oooo000P0?ooo`030000003oool0oooo
0?l0ooooU@3oool00`000000oooo0?ooo`0:0?ooo`80000000<0oooo0000000000001P00003]0?oo
o`00803oool00`000000oooo0?ooo`3o0?oooiD0oooo00<000000?ooo`3oool0303oool900000080
oooo0P00003Y0?ooo`00803oool00`000000oooo0?ooo`3o0?ooojD0oooo2@0000030?ooo`800000
i`3oool00200oooo00<000000?ooo`3oool0o`3ooonV0?ooo`H000000P3oool2000000<0oooo0P00
000?0?ooo`030000003oool0oooo0=<0oooo000P0?ooo`030000003oool0oooo0?l0ooooZ03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`3C0?ooo`00803oool00`000000oooo0?ooo`3o0?ooojP0oooo00<000000?oo
o`3oool01P3oool200000140oooo00<000000?ooo`3oool0d`3oool00200oooo00<000000?ooo`3o
ool0o`3ooonX0?ooo`050000003oool0oooo0?ooo`0000001P3oool2000000l0oooo00<000000?oo
o`3oool0d`3oool00200oooo00<000000?ooo`3oool0o`3ooonX0?ooo`030000003oool0oooo0080
oooo0P0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3C0?ooo`00803oool00`000000oooo0?ooo`3o0?ooojP0oooo00<000000?ooo`3oool0
103oool2000000D0oooo0P0000030?ooo`8000001`3oool00`000000oooo0?ooo`3C0?ooo`00803o
ool00`000000oooo0?ooo`3o0?ooojP0oooo00<000000?ooo`3oool01P3oool2000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=<0oooo000P
0?ooo`030000003oool0oooo0?l0ooooZ03oool00`000000oooo0?ooo`0>0?ooo`8000000`3oool2
000000@0oooo00<000000?ooo`3oool0d`3oool00200oooo00<000000?ooo`3oool0o`3ooonX0?oo
o`030000003oool0oooo0100oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000e@3oool0
0200oooo00<000000?ooo`3oool0o`3ooonX0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=<0oooo000P0?ooo`<0
0000o`3ooonh0?ooo`800000103oool2000000030?ooo`000000000000@00000d`3oool00200oooo
00<000000?ooo`3oool0o`3ooonj0?ooo`030000003oool0oooo00<0oooo2000003B0?ooo`00803o
ool00`000000oooo0?ooo`3o0?oook/0oooo0P0000030?ooo`P00000dP3oool00200oooo00<00000
0?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo00X00000d03oool00200oooo00<000000?oo
o`3oool0o`3oooo00?ooo`P000000P3oool200000<h0oooo000P0?ooo`030000003oool0oooo0?l0
oooo`03oool800000=80oooo000P0?ooo`030000003oool0oooo0?l0oooo`03oool:00000=00oooo
000P0?ooo`030000003oool0oooo0?l0oooo`@3oool6000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`370?ooo`00803oool00`000000oooo0?ooo`3o0?oool@0oooo0`000004
0?ooo`800000103oool200000<L0oooo000P0?ooo`030000003oool0oooo0?l0ooooa03oool00`00
0000oooo0?ooo`02000000@0oooo0P0000040?ooo`030000003oool0oooo0<@0oooo000P0?ooo`03
0000003oool0oooo0?l0ooooa03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo0P0000340?ooo`00803oool00`000000oooo0?ooo`3o0?oool@0oooo00<000000?ooo`3oool0
2@3oool2000000@0oooo00<000000?ooo`3oool0`@3oool00200oooo00<000000?ooo`3oool0o`3o
ooo40?ooo`030000003oool0oooo00/0oooo0P00000F0?ooo`030000003oool0oooo0:d0oooo000P
0?ooo`030000003oool0oooo0?l0ooooa03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2]0?ooo`00803oool00`00
0000oooo0?ooo`3o0?oool@0oooo00<000000?ooo`3oool01`3oool2000000D0oooo0P0000050?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0[@3oool00200oooo00<000000?ooo`3o
ool0o`3oooo40?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`800000103oool2000000/0
oooo00<000000?ooo`3oool0[@3oool00200oooo00<000000?ooo`3oool0o`3oooo40?ooo`030000
003oool0oooo00/0oooo0P0000050?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000
003oool0oooo0:d0oooo000P0?ooo`030000003oool0oooo0?l0oooofP3oool2000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`2]0?ooo`00803oool00`000000oooo0?ooo`3o
0?ooom`0oooo0P00000<0?ooo`030000003oool0oooo0:d0oooo000P0?ooo`030000003oool0oooo
0?l0oooof03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0[@3oool00200oooo00<000000?ooo`3oool0o`3ooooI0?ooo`800000103oool2000000H0
oooo00@000000?ooo`3oool00000[`3oool00200oooo0`00003o0?ooom/0oooo00<000000?ooo`3o
ool00`3oool2000000D0oooo00<000000?ooo`000000[`3oool00200oooo00<000000?ooo`3oool0
o`3ooooL0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`800000[`3oool00200oooo00<0
00000?ooo`3oool0o`3ooooN0?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`H00000[03o
ool00200oooo00<000000?ooo`3oool0o`3ooooV0?ooo`T00000Z`3oool00200oooo00<000000?oo
o`3oool0o`3ooooW0?ooo`P00000Z`3oool00200oooo00<000000?ooo`3oool0o`3ooooS0?ooo`04
0000003oool0oooo0?ooo`P000005@3oool00`000000oooo0?ooo`2C0?ooo`00803oool00`000000
oooo0?ooo`3o0?ooon@0oooo0P0000000`3oool0000000000006000000<0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`2C0?ooo`00803oool00`000000oooo0?ooo`3o0?ooonH0oooo
2@0000040?ooo`8000003`3oool00`000000oooo0?ooo`2C0?ooo`00803oool00`000000oooo0?oo
o`3o0?ooonL0oooo2@0000050?ooo`8000003@3oool00`000000oooo0?ooo`2C0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooonP0oooo1P0000020?ooo`8000001@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo09<0oooo000P0?ooo`030000003oool0oooo0?l0oooojP3oool00`00
0000oooo0?ooo`050?ooo`800000403oool00`000000oooo0?ooo`2C0?ooo`00803oool00`000000
oooo0?ooo`3o0?ooonX0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0T`3oool00200oooo00<000000?ooo`3oool0
o`3ooooZ0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool2000000d0oooo
00<000000?ooo`3oool0T`3oool00200oooo00<000000?ooo`3oool0o`3ooooZ0?ooo`030000003o
ool0oooo00@0oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0T`3o
ool00200oooo00<000000?ooo`3oool0o`3ooooZ0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0T`3oool00200oooo00<000000?ooo`3oool0o`3ooooZ0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?ooo`030000003oool0oooo
09<0oooo000P0?ooo`030000003oool0oooo0?l0oooojP3oool00`000000oooo0?ooo`0?0?ooo`80
00000`3oool6000009<0oooo000P0?ooo`030000003oool0oooo0?l0oooojP3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0000000L00000TP3oool00200oooo00<000000?ooo`3oool0o`3o
oooZ0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool900000980oooo000P
0?ooo`030000003oool0oooo0?l0oooojP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0080oooo2@00000E0?ooo`030000003oool0oooo07T0oooo000P0?ooo`<00000o`3ooool0?oo
o`8000000P3oool8000000030?ooo`000000000001<0oooo00<000000?ooo`3oool0N@3oool00200
oooo00<000000?ooo`3oool0o`3oooon0?ooo`X000000`3oool200000140oooo00<000000?ooo`3o
ool0N@3oool00200oooo00<000000?ooo`3oool0o`3ooooo0?ooo`40oooo200000050?ooo`800000
3`3oool00`000000oooo0?ooo`1i0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0oooo0P3o
ool6000000030?ooo`000000000001@0oooo00<000000?ooo`3oool0N@3oool00200oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo07T0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3oool50?oo
o`8000001@3oool200000140oooo00<000000?ooo`3oool0N@3oool00200oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`D0oooo00@000000?ooo`00000000001@3oool2000000@0oooo0P0000090?oo
o`030000003oool0oooo07T0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3oool50?ooo`04
0000003oool0oooo0?ooo`8000001@3oool2000000@0oooo0P0000070?ooo`030000003oool0oooo
07T0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3oool50?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000
oooo0?ooo`1i0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0oooo1@3oool00`000000oooo
0?ooo`0;0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07T0oooo
000P0?ooo`030000003oool0oooo0?l0ooooo`3oool50?ooo`030000003oool0oooo00d0oooo0P00
00080?ooo`030000003oool0oooo07T0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3oool5
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool2000000@0oooo1P00001h
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0oooo1@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02000001g0?ooo`00803oool00`000000
oooo0?ooo`3o0?ooool0oooo1@3oool00`000000oooo0?ooo`0;0?ooo`8000001@3oool:000007L0
oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3oool50?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0103oool8000007L0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3o
ool50?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool:000001D0oooo00<0
00000?ooo`3oool0G@3oool00200oooo00<000000?ooo`3oool0o`3ooooo0?oooa`0oooo2000000G
0?ooo`030000003oool0oooo05d0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3ooolL0?oo
o`P000005`3oool00`000000oooo0?ooo`1M0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0
oooo703oool8000001L0oooo00<000000?ooo`3oool0G@3oool000d0oooo0P0000040?ooo`800000
2`3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool3000000@0oooo0P0000040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0G@3oool000`0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooo`3ooolO0?ooo`80
00001@3oool2000000<0oooo0P00000>0?ooo`030000003oool0oooo05d0oooo000<0?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000002P3oool500000?l0ooooo`3ooolM0?oo
o`030000003oool0000000H0oooo00<000000?ooo`3oool00P3oool2000000`0oooo00<000000?oo
o`3oool0G@3oool000d0oooo0P0000030?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool0o`3ooooo0?oooal0oooo00<000000?ooo`3oool01`3oool2000000@0oooo0P00000:0?oo
o`030000003oool0oooo05d0oooo000<0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`3o0?ooool0oooo7`3oool00`000000oooo0?ooo`09
0?ooo`8000003P3oool00`000000oooo0?ooo`1M0?ooo`00303oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3ooooo0?oooal0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05d0oooo000=
0?ooo`800000103oool2000000/0oooo00<000000?ooo`3oool0o`3ooooo0?oooal0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo05d0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3ooolO0?oo
o`030000003oool0oooo00H0oooo0P0000060?ooo`800000103oool2000000<0oooo00<000000?oo
o`3oool0G@3oool00200oooo00<000000?ooo`3oool0o`3ooooo0?oooal0oooo00<000000?ooo`3o
ool0203oool2000000H0oooo00<000000?ooo`3oool00`3oool7000005`0oooo000P0?ooo`030000
003oool0oooo0?l0ooooo`3ooolO0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
103oool2000000<0oooo2000001K0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0oooo7`3o
ool00`000000oooo0?ooo`0C0?ooo`80000000<0oooo0000000000001P00001K0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooool0oooo7`3oool00`000000oooo0?ooo`0E0?ooo`T00000F`3oool0
0200oooo00<000000?ooo`3oool0o`3ooooo0?oooc80oooo00<000000?ooo`3oool00`3oool80000
05/0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3ooolc0?ooo`030000003oool0oooo0080
oooo200000000`3oool000000?ooo`1H0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0oooo
=03oool200000080oooo200000020?ooo`800000E`3oool00200oooo00<000000?ooo`3oool0o`3o
oooo0?ooocH0oooo00<000000?ooo`3oool01P0000050?ooo`800000E@3oool00200oooo00<00000
0?ooo`3oool0o`3ooooo0?ooocL0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0DP3oool00200oooo00<000000?ooo`3oool0o`3ooooo
0?oooc/0oooo00<000000?ooo`3oool00P3oool2000005T0oooo000P0?ooo`030000003oool0oooo
0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00@0oooo0P00001G0?ooo`00803oool00`000000
oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo000000060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`02000000D0oooo0P0000060?ooo`800000
5@3oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0oooo>`3o
ool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`8000004`3o
ool00`000000oooo0?ooo`0d0?ooo`00803oool300000?l0ooooo`3ooolk0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool2000000L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0d0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0oooo>`3oool00`00
0000oooo0?ooo`0<0?ooo`800000603oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000
oooo0?ooo`3o0?ooool0oooo>`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0=03oool00200oooo00<000000?ooo`3oool0o`3ooooo0?oooc/0oooo
00<000000?ooo`3oool03`3oool2000001D0oooo00<000000?ooo`3oool0=03oool00200oooo00<0
00000?ooo`3oool0o`3ooooo0?oooc/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`040?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03@0oooo000P
0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00/0oooo0P000006
0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`030000003oool0oooo03@0oooo000P0?oo
o`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`030000003oool0oooo00d0oooo0P0000050?oo
o`8000001P3oool2000000P0oooo00<000000?ooo`3oool0=03oool00200oooo00<000000?ooo`3o
ool0o`3ooooo0?ooodd0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0oooo
EP3oool2000000`0oooo00<000000?ooo`3oool0=03oool00200oooo00<000000?ooo`3oool0o`3o
oooo0?oooeP0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooool0ooooD`3oool00`000000oooo0?ooo`030?ooo`8000001`3oool6
000003<0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3ooomD0?ooo`8000001@3oool20000
00@0oooo2000000b0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0ooooEP3oool2000000D0
oooo00@000000?ooo`3oool0oooo2000000b0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0
ooooF03oool00`000000oooo0?ooo`030?ooo`80000000<0oooo0000000000001P00000b0?ooo`00
803oool00`000000oooo0?ooo`3o0?ooool0ooooH03oool900000380oooo000P0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomQ0?ooo`P00000<P3oool00200oooo00<000000?ooo`3oool0o`3ooooo
0?ooof40oooo2000000b0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0ooooGP3oool01000
0000oooo0?ooo`3oool6000003<0oooo000P0?ooo`030000003oool0oooo0?l0ooooo`3ooomO0?oo
o`8000000`3oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0
ooooH@3oool2000000030?ooo`000000oooo03D0oooo000P0?ooo`<00000o`3ooooo0?ooof<0oooo
0P00000f0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?oo
o`0d0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d
0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d0?oo
o`00803oool00`000000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d0?ooo`00
803oool00`000000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d0?ooo`00803o
ool00`000000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d0?ooo`00803oool0
0`000000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d0?ooo`00803oool00`00
0000oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000
oooo0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000oooo
0?ooo`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000oooo0?oo
o`3o0?ooool0ooooI03oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000oooo0?ooo`3o
0?ooool0ooooV`3oool00200oooo00<000000?ooo`3oool0o`3ooooo0?oooi/0oooo000P0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonK0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0oooo
V`3oool00200oooo00<000000?ooo`3oool0o`3ooooo0?oooi/0oooo000P0?ooo`030000003oool0
oooo0?l0ooooo`3ooonK0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0ooooV`3oool00200
oooo00<000000?ooo`3oool0o`3ooooo0?oooi/0oooo000P0?ooo`030000003oool0oooo0?l0oooo
o`3ooonK0?ooo`00803oool00`000000oooo0?ooo`3o0?ooool0ooooV`3oool00?l0ooooo`3ooonn
0?ooo`00o`3ooooo0?oookh0oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3o
oooo0?oookh0oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0
oooo003o0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooom00?ooo`80000000@0oooo
0000003oool0oooo0P0000000`3oool000000?ooo`020?ooo`8000000`3oool2000000030?ooo`00
0000oooo00<00000103oool3000000@0oooo0P00003o0?oooeL0oooo003o0?ooocl0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`060000003oool0oooo0000003o
ool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000H0oooo00@00000
0?ooo`3oool00000o`3ooomF0?ooo`00o`3ooolo0?ooo`040000003oool0oooo000000<0oooo0`00
00030?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`8000000`3oool3000000@0oooo00<0
00000?ooo`3oool0o`3ooomG0?ooo`00o`3ooolo0?ooo`040000003oool0oooo000000D0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`3o0?oooeL0oooo003o0?oood00oooo0`0000030?ooo`80
00000`3oool4000000<0oooo0P0000040?ooo`<000000`3oool2000000<0oooo1000003o0?oooeL0
oooo003o0?oood80oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo0?l0ooooE`3oool001d0oooo0P00003o0?ooob80oooo0P0000090?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooool0ooooW03oool001l0oooo0P00003o0?ooool0ooooW@3oool001h0oooo00@000000?ooo`3o
ool00000o`3ooooo0?oooi`0oooo000N0?ooo`040000003oool0oooo00000?l0ooooo`3ooonL0?oo
o`007P3oool010000000oooo0?ooo`00003o0?ooool0ooooW03oool001d0oooo0P0000000`3oool0
00000000003o0?ooool0ooooW03oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 699}, {431.625, 0}} -> {-652.83, -4.16417, 20.3731, \
0.244213}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1400}, {0, 1050}},
ScreenStyleEnvironment->"Working",
WindowSize->{840, 935},
WindowMargins->{{Automatic, 0}, {Automatic, 36}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "goerz", \
"cpprakt"}, "cpgoerz_mi_01.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 34, 0, 98, "Title"],
Cell[1813, 55, 48, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[1886, 62, 27, 0, 74, "Section"],

Cell[CellGroupData[{
Cell[1938, 66, 32, 0, 28, "Subsubsection"],
Cell[1973, 68, 77, 1, 27, "Input"],
Cell[2053, 71, 64, 1, 27, "Input"],
Cell[2120, 74, 66, 1, 27, "Input"],
Cell[2189, 77, 56, 1, 27, "Input"],
Cell[2248, 80, 64, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2349, 86, 64, 0, 28, "Subsubsection"],
Cell[2416, 88, 472, 9, 191, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2925, 102, 39, 0, 22, "Subsubsection"],
Cell[2967, 104, 156, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[3148, 111, 91, 1, 27, "Input"],
Cell[3242, 114, 512, 7, 91, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3815, 128, 28, 0, 74, "Section"],

Cell[CellGroupData[{
Cell[3868, 132, 65, 0, 28, "Subsubsection"],
Cell[3936, 134, 5946, 96, 880, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9919, 235, 84, 1, 22, "Subsubsection"],
Cell[10006, 238, 5955, 95, 866, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15998, 338, 78, 0, 22, "Subsubsection"],
Cell[16079, 340, 3549, 60, 695, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19665, 405, 58, 0, 22, "Subsubsection"],
Cell[19726, 407, 100, 3, 32, "Text"],
Cell[19829, 412, 190, 3, 27, "Input"],
Cell[20022, 417, 216, 4, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[20275, 426, 39, 0, 22, "Subsubsection"],
Cell[20317, 428, 148, 4, 45, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20514, 438, 30, 0, 74, "Section"],

Cell[CellGroupData[{
Cell[20569, 442, 36, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[20630, 446, 71, 1, 27, "Input"],
Cell[20704, 449, 54, 1, 23, "Print"],
Cell[20761, 452, 171, 3, 23, "Print"],
Cell[20935, 457, 391, 11, 41, "Print"],
Cell[21329, 470, 45, 1, 23, "Print"],
Cell[21377, 473, 251, 5, 23, "Print"],
Cell[21631, 480, 265, 5, 23, "Print"],
Cell[21899, 487, 272, 5, 23, "Print"],
Cell[22174, 494, 45, 1, 23, "Print"],
Cell[22222, 497, 221, 4, 25, "Print"],
Cell[22446, 503, 292, 6, 42, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22787, 515, 29, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[22841, 519, 680, 12, 91, "Input"],
Cell[23524, 533, 55759, 1117, 441, 9419, 541, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

